@@ -4,9 +4,9 @@ import { useCallback, useEffect, useMemo, useState } from 'react';
 import * as React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { Text, Box, Button, useStyles2, Space } from '@grafana/ui';
+import { Trans, t } from '@grafana/i18n';
+import { Text, Box, Button, useStyles2 } from '@grafana/ui';
 import { SlideDown } from 'app/core/components/Animations/SlideDown';
-import { Trans, t } from 'app/core/internationalization';
 import { getBackendSrv } from 'app/core/services/backend_srv';
 import { DescendantCount } from 'app/features/browse-dashboards/components/BrowseActions/DescendantCount';
 
@@ -158,7 +158,7 @@ export const Permissions = ({
     <>
       <div>
         {canSetPermissions && resource === 'folders' && (
-          <>
+          <Box paddingBottom={2}>
             <Trans i18nKey="access-control.permissions.permissions-change-warning">
               This will change permissions for this folder and all its descendants. In total, this will affect:
             </Trans>
@@ -170,8 +170,7 @@ export const Permissions = ({
                 $all: false,
               }}
             />
-            <Space v={2} />
-          </>
+          </Box>
         )}
         {items.length === 0 && (
           <Box>
