@@ -5,7 +5,7 @@ import { GrafanaTheme2 } from '@grafana/data';
 import { PanelContainer, useStyles2 } from '@grafana/ui';
 import { CloseButton } from 'app/core/components/CloseButton/CloseButton';
 
-import { Wizard } from '../components/Wizard';
+import { Wizard } from '../components/Wizard/Wizard';
 import { useCorrelations } from '../useCorrelations';
 
 import { ConfigureCorrelationBasicInfoForm } from './ConfigureCorrelationBasicInfoForm';
