@@ -1,6 +1,7 @@
 import { chain } from 'lodash';
 
 import { DataSourceInstanceSettings, SelectableValue } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { config, getDataSourceSrv } from '@grafana/runtime';
 import {
   ConstantVariable,
@@ -16,24 +17,27 @@ import {
   SceneObject,
   AdHocFiltersVariable,
   SceneVariableState,
+  SceneVariableSet,
 } from '@grafana/scenes';
 import { VariableHide, VariableType } from '@grafana/schema';
+import { OptionsPaneItemDescriptor } from 'app/features/dashboard/components/PanelEditor/OptionsPaneItemDescriptor';
 
 import { getIntervalsQueryFromNewIntervalModel } from '../../utils/utils';
 
-import { AdHocFiltersVariableEditor } from './editors/AdHocFiltersVariableEditor';
-import { ConstantVariableEditor } from './editors/ConstantVariableEditor';
-import { CustomVariableEditor } from './editors/CustomVariableEditor';
-import { DataSourceVariableEditor } from './editors/DataSourceVariableEditor';
-import { GroupByVariableEditor } from './editors/GroupByVariableEditor';
-import { IntervalVariableEditor } from './editors/IntervalVariableEditor';
-import { QueryVariableEditor } from './editors/QueryVariableEditor';
-import { TextBoxVariableEditor } from './editors/TextBoxVariableEditor';
+import { AdHocFiltersVariableEditor, getAdHocFilterOptions } from './editors/AdHocFiltersVariableEditor';
+import { ConstantVariableEditor, getConstantVariableOptions } from './editors/ConstantVariableEditor';
+import { CustomVariableEditor, getCustomVariableOptions } from './editors/CustomVariableEditor';
+import { DataSourceVariableEditor, getDataSourceVariableOptions } from './editors/DataSourceVariableEditor';
+import { getGroupByVariableOptions, GroupByVariableEditor } from './editors/GroupByVariableEditor';
+import { getIntervalVariableOptions, IntervalVariableEditor } from './editors/IntervalVariableEditor';
+import { getQueryVariableOptions, QueryVariableEditor } from './editors/QueryVariableEditor';
+import { TextBoxVariableEditor, getTextBoxVariableOptions } from './editors/TextBoxVariableEditor';
 
 interface EditableVariableConfig {
   name: string;
   description: string;
   editor: React.ComponentType<any>;
+  getOptions?: (variable: SceneVariable) => OptionsPaneItemDescriptor[];
 }
 
 //exclude system variable type and snapshot variable type
@@ -43,48 +47,87 @@ export function isEditableVariableType(type: VariableType): type is EditableVari
   return type !== 'system';
 }
 
-export const EDITABLE_VARIABLES: Record<EditableVariableType, EditableVariableConfig> = {
+export const getEditableVariables: () => Record<EditableVariableType, EditableVariableConfig> = () => ({
   custom: {
-    name: 'Custom',
-    description: 'Define variable values manually',
+    name: t('dashboard-scene.get-editable-variables.name.custom', 'Custom'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.values-are-static-and-defined-manually',
+      'Values are static and defined manually'
+    ),
     editor: CustomVariableEditor,
+    getOptions: getCustomVariableOptions,
   },
   query: {
-    name: 'Query',
-    description: 'Variable values are fetched from a datasource query',
+    name: t('dashboard-scene.get-editable-variables.name.query', 'Query'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.values-fetched-source-query',
+      'Values are fetched from a data source query'
+    ),
     editor: QueryVariableEditor,
+    getOptions: getQueryVariableOptions,
   },
   constant: {
-    name: 'Constant',
-    description: 'Define a hidden constant variable, useful for metric prefixes in dashboards you want to share',
+    name: t('dashboard-scene.get-editable-variables.name.constant', 'Constant'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.hidden-constant-variable',
+      'A hidden constant variable, useful for metric prefixes in dashboards you want to share'
+    ),
     editor: ConstantVariableEditor,
+    getOptions: getConstantVariableOptions,
   },
   interval: {
-    name: 'Interval',
-    description: 'Define a timespan interval (ex 1m, 1h, 1d)',
+    name: t('dashboard-scene.get-editable-variables.name.interval', 'Interval'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.values-timespans',
+      'Values are timespans, ex 1m, 1h, 1d'
+    ),
     editor: IntervalVariableEditor,
+    getOptions: getIntervalVariableOptions,
   },
   datasource: {
-    name: 'Data source',
-    description: 'Enables you to dynamically switch the data source for multiple panels',
+    name: t('dashboard-scene.get-editable-variables.name.data-source', 'Data source'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.dynamically-switch-source-multiple-panels',
+      'Dynamically switch the data source for multiple panels'
+    ),
     editor: DataSourceVariableEditor,
+    getOptions: getDataSourceVariableOptions,
   },
   adhoc: {
-    name: 'Ad hoc filters',
-    description: 'Add key/value filters on the fly',
+    name: t('dashboard-scene.get-editable-variables.name.ad-hoc-filters', 'Ad hoc filters'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.add-keyvalue-filters-on-the-fly',
+      'Add key/value filters on the fly'
+    ),
     editor: AdHocFiltersVariableEditor,
+    getOptions: getAdHocFilterOptions,
   },
   groupby: {
-    name: 'Group by',
-    description: 'Add keys to group by on the fly',
+    name: t('dashboard-scene.get-editable-variables.name.group-by', 'Group by'),
+    description: t('dashboard-scene.get-editable-variables.description.group', 'Add keys to group by on the fly'),
     editor: GroupByVariableEditor,
+    getOptions: getGroupByVariableOptions,
   },
   textbox: {
-    name: 'Textbox',
-    description: 'Define a textbox variable, where users can enter any arbitrary string',
+    name: t('dashboard-scene.get-editable-variables.name.textbox', 'Textbox'),
+    description: t(
+      'dashboard-scene.get-editable-variables.description.users-enter-arbitrary-strings-textbox',
+      'Users can enter any arbitrary strings in a textbox'
+    ),
     editor: TextBoxVariableEditor,
+    getOptions: getTextBoxVariableOptions,
   },
-};
+});
+
+export function getEditableVariableDefinition(type: string): EditableVariableConfig {
+  const editableVariables = getEditableVariables();
+  const editableVariable = editableVariables[type as EditableVariableType];
+  if (!editableVariable) {
+    throw new Error(`Variable type ${type} not found`);
+  }
+
+  return editableVariable;
+}
 
 export const EDITABLE_VARIABLES_SELECT_ORDER: EditableVariableType[] = [
   'query',
@@ -98,10 +141,11 @@ export const EDITABLE_VARIABLES_SELECT_ORDER: EditableVariableType[] = [
 ];
 
 export function getVariableTypeSelectOptions(): Array<SelectableValue<EditableVariableType>> {
+  const editableVariables = getEditableVariables();
   const results = EDITABLE_VARIABLES_SELECT_ORDER.map((variableType) => ({
-    label: EDITABLE_VARIABLES[variableType].name,
+    label: editableVariables[variableType].name,
     value: variableType,
-    description: EDITABLE_VARIABLES[variableType].description,
+    description: editableVariables[variableType].description,
   }));
 
   if (!config.featureToggles.groupByVariable) {
@@ -113,7 +157,8 @@ export function getVariableTypeSelectOptions(): Array<SelectableValue<EditableVa
 }
 
 export function getVariableEditor(type: EditableVariableType) {
-  return EDITABLE_VARIABLES[type].editor;
+  const editableVariables = getEditableVariables();
+  return editableVariables[type].editor;
 }
 
 interface CommonVariableProperties {
@@ -197,12 +242,10 @@ export function getOptionDataSourceTypes() {
     })
     .value();
 
-  optionTypes.unshift({ label: '', value: '' });
-
   return optionTypes;
 }
 
-function isSceneVariable(sceneObject: SceneObject): sceneObject is SceneVariable {
+export function isSceneVariable(sceneObject: SceneObject): sceneObject is SceneVariable {
   return 'type' in sceneObject.state && 'getValue' in sceneObject;
 }
 
@@ -225,3 +268,32 @@ export function isSceneVariableInstance(sceneObject: SceneObject): sceneObject i
 
 export const RESERVED_GLOBAL_VARIABLE_NAME_REGEX = /^(?!__).*$/;
 export const WORD_CHARACTERS_REGEX = /^\w+$/;
+
+export function validateVariableName(
+  variable: SceneVariable,
+  name: string
+): { isValid: boolean; errorMessage?: string } {
+  const set = variable.parent;
+  if (!(set instanceof SceneVariableSet)) {
+    throw new Error('Variable parent is not a SceneVariableSet');
+  }
+
+  if (!RESERVED_GLOBAL_VARIABLE_NAME_REGEX.test(name)) {
+    return {
+      isValid: false,
+      errorMessage: "Template names cannot begin with '__', that's reserved for Grafana's global variables",
+    };
+  }
+
+  if (!WORD_CHARACTERS_REGEX.test(name)) {
+    return { isValid: false, errorMessage: 'Only word characters are allowed in variable names' };
+  }
+
+  const varLookupByName = set.getByName(name);
+
+  if (varLookupByName && varLookupByName !== variable) {
+    return { isValid: false, errorMessage: 'Variable with the same name already exists' };
+  }
+
+  return { isValid: true };
+}
