@@ -1,10 +1,11 @@
 import { useMemo } from 'react';
 import useAsync from 'react-use/lib/useAsync';
 
-import { DataQueryError, DataSourceApi, PanelData, PanelPlugin } from '@grafana/data';
+import { DataSourceApi, PanelData, PanelPlugin } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { getDataSourceSrv } from '@grafana/runtime';
-import { t } from 'app/core/internationalization';
-import { DashboardModel, PanelModel } from 'app/features/dashboard/state';
+import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
+import { PanelModel } from 'app/features/dashboard/state/PanelModel';
 import { InspectTab } from 'app/features/inspector/types';
 
 import { supportsDataQuery } from '../PanelEditor/utils';
@@ -13,25 +14,27 @@ import { supportsDataQuery } from '../PanelEditor/utils';
  * Given PanelData return first data source supporting metadata inspector
  */
 export const useDatasourceMetadata = (data?: PanelData) => {
-  const state = useAsync(async () => {
-    const targets = data?.request?.targets || [];
+  const state = useAsync(async () => getDataSourceWithInspector(data), [data]);
+  return state.value;
+};
 
-    if (data && data.series && targets.length) {
-      for (const frame of data.series) {
-        if (frame.meta && frame.meta.custom) {
-          // get data source from first query
-          const dataSource = await getDataSourceSrv().get(targets[0].datasource);
-          if (dataSource && dataSource.components?.MetadataInspector) {
-            return dataSource;
-          }
+export async function getDataSourceWithInspector(data?: PanelData): Promise<DataSourceApi | undefined> {
+  const targets = data?.request?.targets || [];
+
+  if (data && data.series && targets.length) {
+    for (const frame of data.series) {
+      if (frame.meta && frame.meta.custom) {
+        // get data source from first query
+        const dataSource = await getDataSourceSrv().get(targets[0].datasource);
+        if (dataSource && dataSource.components?.MetadataInspector) {
+          return dataSource;
         }
       }
     }
+  }
 
-    return undefined;
-  }, [data]);
-  return state.value;
-};
+  return undefined;
+}
 
 /**
  * Configures tabs for PanelInspector
@@ -40,7 +43,7 @@ export const useInspectTabs = (
   panel: PanelModel,
   dashboard: DashboardModel,
   plugin: PanelPlugin | undefined | null,
-  error?: DataQueryError,
+  hasError?: boolean,
   metaDs?: DataSourceApi
 ) => {
   return useMemo(() => {
@@ -51,12 +54,12 @@ export const useInspectTabs = (
     }
 
     if (metaDs) {
-      tabs.push({ label: t('dashboard.inspect.meta-tab', 'Meta Data'), value: InspectTab.Meta });
+      tabs.push({ label: t('dashboard.inspect.meta-tab', 'Meta data'), value: InspectTab.Meta });
     }
 
     tabs.push({ label: t('dashboard.inspect.json-tab', 'JSON'), value: InspectTab.JSON });
 
-    if (error && error.message) {
+    if (hasError) {
       tabs.push({ label: t('dashboard.inspect.error-tab', 'Error'), value: InspectTab.Error });
     }
 
@@ -64,5 +67,5 @@ export const useInspectTabs = (
       tabs.push({ label: t('dashboard.inspect.query-tab', 'Query'), value: InspectTab.Query });
     }
     return tabs;
-  }, [plugin, metaDs, dashboard, error]);
+  }, [plugin, metaDs, dashboard, hasError]);
 };
