@@ -1,8 +1,10 @@
 import { fireEvent, render, screen } from '@testing-library/react';
-import React, { ComponentProps } from 'react';
+import { ComponentProps } from 'react';
+
+import { Field, CoreApp, FieldType, LinkModel } from '@grafana/data';
 
 import { LogDetailsRow } from './LogDetailsRow';
-import { createLogRow } from './__mocks__/logRow';
+import { createLogRow } from './mocks/logRow';
 
 type Props = ComponentProps<typeof LogDetailsRow>;
 
@@ -20,6 +22,7 @@ const setup = (propOverrides?: Partial<Props>) => {
     displayedFields: [],
     row: createLogRow(),
     disableActions: false,
+    app: CoreApp.Explore,
   };
 
   Object.assign(props, propOverrides);
@@ -140,8 +143,38 @@ describe('LogDetailsRow', () => {
     it('should be invisible unless mouse is over', () => {
       setup({ parsedValues: ['test value'] });
       // This tests a regression where the button was always visible.
-      expect(screen.getByTitle('Copy value to clipboard')).not.toBeVisible();
+      expect(screen.getByLabelText('Copy value to clipboard')).not.toBeVisible();
       // Asserting visibility on mouse-over is currently not possible.
     });
   });
+
+  describe('datalinks', () => {
+    it('datalinks should pin and call the original link click', () => {
+      const onLinkClick = jest.fn();
+      const onPinLine = jest.fn();
+      const links: Array<LinkModel<Field>> = [
+        {
+          onClick: onLinkClick,
+          href: '#',
+          title: 'Hello link',
+          target: '_self',
+          origin: {
+            name: 'name',
+            type: FieldType.string,
+            config: {},
+            values: ['string'],
+          },
+        },
+      ];
+      setup({ links, onPinLine });
+
+      expect(onLinkClick).not.toHaveBeenCalled();
+      expect(onPinLine).not.toHaveBeenCalled();
+
+      fireEvent.click(screen.getByRole('button', { name: 'Hello link' }));
+
+      expect(onLinkClick).toHaveBeenCalled();
+      expect(onPinLine).toHaveBeenCalled();
+    });
+  });
 });
