@@ -69,7 +69,7 @@ const mocks: Record<string, any> = {
 
 setDataSourceSrv(mocks.dataSourceSrv as DataSourceSrv);
 
-jest.mock('../../plugins/plugin_loader', () => ({
+jest.mock('../../plugins/pluginLoader', () => ({
   importDataSourcePlugin: () => mocks.pluginLoader.importDataSourcePlugin(),
 }));
 
