@@ -8,9 +8,16 @@ import {
   updateDatasourcePluginJsonDataOption,
   updateDatasourcePluginResetOption,
 } from '@grafana/data';
-import { ConfigSection, ConfigSubSection, DataSourceDescription, Stack } from '@grafana/experimental';
+import { ConfigSection, ConfigSubSection, DataSourceDescription, EditorStack } from '@grafana/plugin-ui';
 import { config } from '@grafana/runtime';
-import { ConnectionLimits, Divider, TLSSecretsConfig, useMigrateDatabaseFields } from '@grafana/sql';
+import {
+  ConnectionLimits,
+  Divider,
+  MaxLifetimeField,
+  MaxOpenConnectionsField,
+  TLSSecretsConfig,
+  useMigrateDatabaseFields,
+} from '@grafana/sql';
 import {
   Input,
   Select,
@@ -76,6 +83,14 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
     };
   };
 
+  const onMaxConnectionsChanged = (number?: number) => {
+    updateDatasourcePluginJsonDataOption(props, 'maxOpenConns', number);
+  };
+
+  const onMaxLifetimeChanged = (number?: number) => {
+    updateDatasourcePluginJsonDataOption(props, 'connMaxLifetime', number);
+  };
+
   const onTimeScaleDBChanged = (event: SyntheticEvent<HTMLInputElement>) => {
     updateDatasourcePluginJsonDataOption(props, 'timescaledb', event.currentTarget.checked);
   };
@@ -157,7 +172,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
         <Field
           label={
             <Label>
-              <Stack gap={0.5}>
+              <EditorStack gap={0.5}>
                 <span>TLS/SSL Mode</span>
                 <Tooltip
                   content={
@@ -169,7 +184,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                 >
                   <Icon name="info-circle" size="sm" />
                 </Tooltip>
-              </Stack>
+              </EditorStack>
             </Label>
           }
         >
@@ -185,7 +200,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
           <Field
             label={
               <Label>
-                <Stack gap={0.5}>
+                <EditorStack gap={0.5}>
                   <span>TLS/SSL Method</span>
                   <Tooltip
                     content={
@@ -205,7 +220,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                   >
                     <Icon name="info-circle" size="sm" />
                   </Tooltip>
-                </Stack>
+                </EditorStack>
               </Label>
             }
           >
@@ -236,7 +251,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                 <Field
                   label={
                     <Label>
-                      <Stack gap={0.5}>
+                      <EditorStack gap={0.5}>
                         <span>TLS/SSL Root Certificate</span>
                         <Tooltip
                           content={
@@ -248,7 +263,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                         >
                           <Icon name="info-circle" size="sm" />
                         </Tooltip>
-                      </Stack>
+                      </EditorStack>
                     </Label>
                   }
                 >
@@ -262,7 +277,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                 <Field
                   label={
                     <Label>
-                      <Stack gap={0.5}>
+                      <EditorStack gap={0.5}>
                         <span>TLS/SSL Client Certificate</span>
                         <Tooltip
                           content={
@@ -274,7 +289,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                         >
                           <Icon name="info-circle" size="sm" />
                         </Tooltip>
-                      </Stack>
+                      </EditorStack>
                     </Label>
                   }
                 >
@@ -288,7 +303,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                 <Field
                   label={
                     <Label>
-                      <Stack gap={0.5}>
+                      <EditorStack gap={0.5}>
                         <span>TLS/SSL Client Key</span>
                         <Tooltip
                           content={
@@ -301,7 +316,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                         >
                           <Icon name="info-circle" size="sm" />
                         </Tooltip>
-                      </Stack>
+                      </EditorStack>
                     </Label>
                   }
                 >
@@ -325,7 +340,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
           <Field
             label={
               <Label>
-                <Stack gap={0.5}>
+                <EditorStack gap={0.5}>
                   <span>Version</span>
                   <Tooltip
                     content={
@@ -334,7 +349,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                   >
                     <Icon name="info-circle" size="sm" />
                   </Tooltip>
-                </Stack>
+                </EditorStack>
               </Label>
             }
           >
@@ -348,7 +363,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
           <Field
             label={
               <Label>
-                <Stack gap={0.5}>
+                <EditorStack gap={0.5}>
                   <span>Min time interval</span>
                   <Tooltip
                     content={
@@ -361,7 +376,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                   >
                     <Icon name="info-circle" size="sm" />
                   </Tooltip>
-                </Stack>
+                </EditorStack>
               </Label>
             }
           >
@@ -375,7 +390,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
           <Field
             label={
               <Label>
-                <Stack gap={0.5}>
+                <EditorStack gap={0.5}>
                   <span>TimescaleDB</span>
                   <Tooltip
                     content={
@@ -389,7 +404,7 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
                   >
                     <Icon name="info-circle" size="sm" />
                   </Tooltip>
-                </Stack>
+                </EditorStack>
               </Label>
             }
           >
@@ -397,8 +412,18 @@ export const PostgresConfigEditor = (props: DataSourcePluginOptionsEditorProps<P
           </Field>
         </ConfigSubSection>
 
-        <ConnectionLimits options={options} onOptionsChange={onOptionsChange} />
-
+        {config.featureToggles.postgresDSUsePGX ? (
+          <ConfigSubSection title="Connection limits">
+            <MaxOpenConnectionsField
+              labelWidth={WIDTH_LONG}
+              jsonData={jsonData}
+              onMaxConnectionsChanged={onMaxConnectionsChanged}
+            />
+            <MaxLifetimeField labelWidth={WIDTH_LONG} jsonData={jsonData} onMaxLifetimeChanged={onMaxLifetimeChanged} />
+          </ConfigSubSection>
+        ) : (
+          <ConnectionLimits options={options} onOptionsChange={onOptionsChange} />
+        )}
         {config.secureSocksDSProxyEnabled && (
           <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
         )}
