@@ -8,9 +8,9 @@ export const textPanelMigrationHandler = (panel: PanelModel<Options>): Partial<O
 
   // Migrates old Angular based text panel props to new props
   if (panel.hasOwnProperty('content') && panel.hasOwnProperty('mode')) {
-    const oldTextPanel: any = panel as any;
+    const oldTextPanel: any = panel;
     const content = oldTextPanel.content;
-    const mode = oldTextPanel.mode as TextMode;
+    const mode: TextMode = oldTextPanel.mode;
 
     delete oldTextPanel.content;
     delete oldTextPanel.mode;
